@@ -36,8 +36,4 @@ public class CMSGCModule extends GCModule {
         return "ParNew";
     }
 
-    @Override
-    protected String getNormalGCName() {
-        return null;
-    }
 }
