@@ -68,6 +68,18 @@ public class ArgumentTypeNameMatch implements ElementMatcher<MethodDescription>
         return false;
     }
 
+    /**
+     * To ensure that the hashCode for recreating the XxxInterceptPoint instance is the same as the previous instance,
+     * each ElementMatcher implementation class needs to implement toString() method.
+     */
+    @Override
+    public String toString() {
+        return "ArgumentTypeNameMatch{" +
+                "index=" + index +
+                ", argumentTypeName='" + argumentTypeName + '\'' +
+                '}';
+    }
+
     /**
      * The static method to create {@link ArgumentTypeNameMatch} This is a delegate method to follow byte-buddy {@link
      * ElementMatcher}'s code style.
