@@ -20,7 +20,11 @@ package org.apache.skywalking.apm.plugin.grpc.v1.server;
 
 import io.grpc.ServerBuilder;
 
+import java.lang.reflect.Field;
 import java.lang.reflect.Method;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 
 import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.EnhancedInstance;
 import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.InstanceMethodsAroundInterceptor;
@@ -30,14 +34,26 @@ import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.MethodInt
  * {@link AbstractServerImplBuilderInterceptor} add the {@link ServerInterceptor} interceptor for every ServerService.
  */
 public class AbstractServerImplBuilderInterceptor implements InstanceMethodsAroundInterceptor {
+    private final static Map<Class<?>, Field> FIELD_CACHE = new HashMap<>();
+
     @Override
     public void beforeMethod(EnhancedInstance objInst, Method method, Object[] allArguments, Class<?>[] argumentsTypes,
-        MethodInterceptResult result) {
+                             MethodInterceptResult result) throws Throwable {
         if (objInst.getSkyWalkingDynamicField() == null) {
             ServerBuilder<?> builder = (ServerBuilder) objInst;
-            ServerInterceptor interceptor = new ServerInterceptor();
-            builder.intercept(interceptor);
-            objInst.setSkyWalkingDynamicField(interceptor);
+            Field field = findField(builder.getClass());
+            if (field != null) {
+                List<?> interceptors = (List<?>) field.get(builder);
+                boolean hasCustomInterceptor = interceptors.stream()
+                        .anyMatch(i -> i.getClass() == ServerInterceptor.class);
+
+                if (!hasCustomInterceptor) {
+                    ServerInterceptor interceptor = new ServerInterceptor();
+                    builder.intercept(interceptor);
+                    objInst.setSkyWalkingDynamicField(interceptor);
+                }
+
+            }
         }
     }
 
@@ -52,4 +68,31 @@ public class AbstractServerImplBuilderInterceptor implements InstanceMethodsArou
         Class<?>[] argumentsTypes, Throwable t) {
 
     }
+
+    private static Field findField(Class<?> clazz) {
+        if (FIELD_CACHE.containsKey(clazz)) {
+            return FIELD_CACHE.get(clazz);
+        }
+        synchronized (AbstractServerImplBuilderInterceptor.class) {
+            if (FIELD_CACHE.containsKey(clazz)) {
+                return FIELD_CACHE.get(clazz);
+            }
+            Field field = doFindField(clazz);
+            FIELD_CACHE.put(clazz, field);
+            return field;
+        }
+    }
+
+    private static Field doFindField(Class<?> clazz) {
+        while (clazz != null) {
+            for (Field f : clazz.getDeclaredFields()) {
+                if (f.getName().equals("interceptors")) {
+                    f.setAccessible(true);
+                    return f;
+                }
+            }
+            clazz = clazz.getSuperclass();
+        }
+        return null;
+    }
 }
