@@ -18,38 +18,46 @@
 
 package org.apache.skywalking.apm.plugin.grpc.v1.server;
 
-import static org.apache.skywalking.apm.plugin.grpc.v1.Constants.RESPONSE_ON_CLOSE_OPERATION_NAME;
-import static org.apache.skywalking.apm.plugin.grpc.v1.Constants.RESPONSE_ON_MESSAGE_OPERATION_NAME;
-import static org.apache.skywalking.apm.plugin.grpc.v1.Constants.SERVER;
-
 import io.grpc.ForwardingServerCall;
 import io.grpc.Metadata;
 import io.grpc.ServerCall;
 import io.grpc.Status;
 import org.apache.skywalking.apm.agent.core.context.ContextManager;
+import org.apache.skywalking.apm.agent.core.context.ContextSnapshot;
 import org.apache.skywalking.apm.agent.core.context.tag.Tags;
 import org.apache.skywalking.apm.agent.core.context.trace.AbstractSpan;
 import org.apache.skywalking.apm.agent.core.context.trace.SpanLayer;
 import org.apache.skywalking.apm.network.trace.component.ComponentsDefine;
 import org.apache.skywalking.apm.plugin.grpc.v1.OperationNameFormatUtil;
 
+import static org.apache.skywalking.apm.plugin.grpc.v1.Constants.RESPONSE_ON_CLOSE_OPERATION_NAME;
+import static org.apache.skywalking.apm.plugin.grpc.v1.Constants.RESPONSE_ON_MESSAGE_OPERATION_NAME;
+import static org.apache.skywalking.apm.plugin.grpc.v1.Constants.SERVER;
+
 public class TracingServerCall<REQUEST, RESPONSE> extends ForwardingServerCall.SimpleForwardingServerCall<REQUEST, RESPONSE> {
 
     private final String operationPrefix;
+    private final ContextSnapshot contextSnapshot;
+    private final AbstractSpan parentEntrySpan;
 
-    protected TracingServerCall(ServerCall<REQUEST, RESPONSE> delegate) {
+    protected TracingServerCall(ServerCall<REQUEST, RESPONSE> delegate,
+                                final ContextSnapshot contextSnapshot,
+                                final AbstractSpan parentEntrySpan) {
         super(delegate);
         this.operationPrefix = OperationNameFormatUtil.formatOperationName(delegate.getMethodDescriptor()) + SERVER;
+        this.contextSnapshot = contextSnapshot;
+        this.parentEntrySpan = parentEntrySpan;
     }
 
     @Override
     public void sendMessage(RESPONSE message) {
         // We just create the request on message span for server stream calls.
         if (!getMethodDescriptor().getType().serverSendsOneMessage()) {
-            final AbstractSpan span = ContextManager.createLocalSpan(operationPrefix + RESPONSE_ON_MESSAGE_OPERATION_NAME);
+            final AbstractSpan span = ContextManager.createLocalSpan(
+                operationPrefix + RESPONSE_ON_MESSAGE_OPERATION_NAME);
             span.setComponent(ComponentsDefine.GRPC);
             span.setLayer(SpanLayer.RPC_FRAMEWORK);
-            ContextManager.continued(ServerInterceptor.CONTEXT_SNAPSHOT_KEY.get());
+            ContextManager.continued(contextSnapshot);
             try {
                 super.sendMessage(message);
             } catch (Throwable t) {
@@ -68,7 +76,7 @@ public class TracingServerCall<REQUEST, RESPONSE> extends ForwardingServerCall.S
         final AbstractSpan span = ContextManager.createLocalSpan(operationPrefix + RESPONSE_ON_CLOSE_OPERATION_NAME);
         span.setComponent(ComponentsDefine.GRPC);
         span.setLayer(SpanLayer.RPC_FRAMEWORK);
-        ContextManager.continued(ServerInterceptor.CONTEXT_SNAPSHOT_KEY.get());
+        ContextManager.continued(contextSnapshot);
         switch (status.getCode()) {
             case OK:
                 break;
@@ -94,7 +102,7 @@ public class TracingServerCall<REQUEST, RESPONSE> extends ForwardingServerCall.S
                 break;
         }
         Tags.RPC_RESPONSE_STATUS_CODE.set(span, status.getCode().name());
-        ServerInterceptor.ACTIVE_SPAN_KEY.get().asyncFinish();
+        parentEntrySpan.asyncFinish();
 
         try {
             super.close(status, trailers);
