@@ -20,13 +20,14 @@ package org.apache.skywalking.apm.plugin.mongodb.v4.interceptor.operation;
 
 import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.EnhancedInstance;
 import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.InstanceConstructorInterceptor;
+import org.apache.skywalking.apm.plugin.mongodb.v4.support.MongoNamespaceInfo;
 
 public class OperationDatabaseConstructInterceptor implements InstanceConstructorInterceptor {
 
     @Override
     public void onConstruct(EnhancedInstance objInst, Object[] allArguments) {
         String databaseName = (String) allArguments[0];
-        objInst.setSkyWalkingDynamicField(databaseName);
+        objInst.setSkyWalkingDynamicField(new MongoNamespaceInfo(databaseName));
     }
 
 }
\ No newline at end of file
