@@ -25,11 +25,8 @@ public class WrappedMapReduceReadOperationInterceptor implements InstanceConstru
 
     @Override
     public void onConstruct(EnhancedInstance objInst, Object[] allArguments) {
-        if (allArguments[0] instanceof EnhancedInstance) {
             EnhancedInstance enhancedInstance = (EnhancedInstance) allArguments[0];
-            String databaseName = (String) enhancedInstance.getSkyWalkingDynamicField();
-            objInst.setSkyWalkingDynamicField(databaseName);
-        }
+            objInst.setSkyWalkingDynamicField(enhancedInstance.getSkyWalkingDynamicField());
     }
 
 }
