@@ -18,6 +18,13 @@
 
 package org.apache.skywalking.apm.plugin.pulsar.common;
 
+import static org.apache.skywalking.apm.network.trace.component.ComponentsDefine.PULSAR_CONSUMER;
+import static org.hamcrest.CoreMatchers.is;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertThat;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
 import java.util.List;
 import org.apache.pulsar.client.api.Consumer;
 import org.apache.pulsar.client.api.MessageListener;
@@ -43,18 +50,8 @@ import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.modules.junit4.PowerMockRunner;
-import org.powermock.modules.junit4.PowerMockRunnerDelegate;
 
-import static org.apache.skywalking.apm.network.trace.component.ComponentsDefine.PULSAR_CONSUMER;
-import static org.hamcrest.CoreMatchers.is;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThat;
-
-@RunWith(PowerMockRunner.class)
-@PowerMockRunnerDelegate(TracingSegmentRunner.class)
+@RunWith(TracingSegmentRunner.class)
 public class PulsarConsumerListenerInterceptorTest {
     @Rule
     public AgentServiceRule serviceRule = new AgentServiceRule();
@@ -141,15 +138,15 @@ public class PulsarConsumerListenerInterceptorTest {
     }
 
     private EnhancedInstance mockConsumer() {
-        EnhancedInstance pulsarProducerInstance = PowerMockito.mock(MockConsumerImpl.class);
-        final LookupService lookup = PowerMockito.mock(LookupService.class);
-        final PulsarClientImpl client = PowerMockito.mock(PulsarClientImpl.class);
+        MockConsumerImpl pulsarProducerInstance = mock(MockConsumerImpl.class);
+        final LookupService lookup = mock(LookupService.class);
+        final PulsarClientImpl client = mock(PulsarClientImpl.class);
         try {
-            PowerMockito.when(lookup, "getServiceUrl").thenReturn("pulsar://localhost:6650");
-            PowerMockito.when(client, "getLookup").thenReturn(lookup);
-            PowerMockito.when(pulsarProducerInstance, "getClient").thenReturn(client);
-            PowerMockito.when(pulsarProducerInstance, "getTopic").thenReturn("persistent://my-tenant/my-ns/my-topic");
-            PowerMockito.when(pulsarProducerInstance, "getSkyWalkingDynamicField").thenReturn("my-sub");
+            when(lookup.getServiceUrl()).thenReturn("pulsar://localhost:6650");
+            when(client.getLookup()).thenReturn(lookup);
+            when(pulsarProducerInstance.getClient()).thenReturn(client);
+            when(pulsarProducerInstance.getTopic()).thenReturn("persistent://my-tenant/my-ns/my-topic");
+            when(pulsarProducerInstance.getSkyWalkingDynamicField()).thenReturn("my-sub");
         } catch (Exception e) {
             throw new RuntimeException(e);
         }
