@@ -18,6 +18,11 @@
 
 package org.apache.skywalking.apm.plugin.pulsar.common;
 
+import static org.apache.skywalking.apm.network.trace.component.ComponentsDefine.PULSAR_PRODUCER;
+import static org.hamcrest.CoreMatchers.is;
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
 import java.util.List;
 import org.apache.pulsar.client.impl.LookupService;
 import org.apache.pulsar.client.impl.MessageImpl;
@@ -36,16 +41,8 @@ import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.modules.junit4.PowerMockRunner;
-import org.powermock.modules.junit4.PowerMockRunnerDelegate;
 
-import static org.apache.skywalking.apm.network.trace.component.ComponentsDefine.PULSAR_PRODUCER;
-import static org.hamcrest.CoreMatchers.is;
-import static org.hamcrest.MatcherAssert.assertThat;
-
-@RunWith(PowerMockRunner.class)
-@PowerMockRunnerDelegate(TracingSegmentRunner.class)
+@RunWith(TracingSegmentRunner.class)
 public class PulsarProducerInterceptorTest {
 
     @SegmentStoragePoint
@@ -74,14 +71,14 @@ public class PulsarProducerInterceptorTest {
     @Test
     public void testSendMessage() throws Throwable {
 
-        EnhancedInstance pulsarProducerInstance = PowerMockito.mock(MockProducerImpl.class);
-        final LookupService lookup = PowerMockito.mock(LookupService.class);
-        final PulsarClientImpl client = PowerMockito.mock(PulsarClientImpl.class);
-        PowerMockito.when(lookup, "getServiceUrl").thenReturn("pulsar://localhost:6650");
-        PowerMockito.when(client, "getLookup").thenReturn(lookup);
-        PowerMockito.when(pulsarProducerInstance, "getClient").thenReturn(client);
-        PowerMockito.when(pulsarProducerInstance, "getTopic").thenReturn("persistent://my-tenant/my-ns/my-topic");
-        PowerMockito.when(pulsarProducerInstance, "getSkyWalkingDynamicField").thenReturn((MessagePropertiesInjector) (message, carrierItem) -> {
+        MockProducerImpl pulsarProducerInstance = mock(MockProducerImpl.class);
+        final LookupService lookup = mock(LookupService.class);
+        final PulsarClientImpl client = mock(PulsarClientImpl.class);
+        when(lookup.getServiceUrl()).thenReturn("pulsar://localhost:6650");
+        when(client.getLookup()).thenReturn(lookup);
+        when(pulsarProducerInstance.getClient()).thenReturn(client);
+        when(pulsarProducerInstance.getTopic()).thenReturn("persistent://my-tenant/my-ns/my-topic");
+        when(pulsarProducerInstance.getSkyWalkingDynamicField()).thenReturn((MessagePropertiesInjector) (message, carrierItem) -> {
             });
         producerInterceptor.beforeMethod(pulsarProducerInstance, null, arguments, argumentType, null);
         producerInterceptor.afterMethod(pulsarProducerInstance, null, arguments, argumentType, null);
@@ -98,8 +95,8 @@ public class PulsarProducerInterceptorTest {
 
     @Test
     public void testSendWithNullMessage() throws Throwable {
-        EnhancedInstance pulsarProducerInstance = PowerMockito.mock(MockProducerImpl.class);
-        PowerMockito.when(pulsarProducerInstance, "getSkyWalkingDynamicField").thenReturn((MessagePropertiesInjector) (message, carrierItem) -> {
+        EnhancedInstance pulsarProducerInstance = mock(MockProducerImpl.class);
+        when(pulsarProducerInstance.getSkyWalkingDynamicField()).thenReturn((MessagePropertiesInjector) (message, carrierItem) -> {
         });
         producerInterceptor.beforeMethod(pulsarProducerInstance, null, new Object[] {null}, argumentType, null);
         producerInterceptor.afterMethod(pulsarProducerInstance, null, new Object[] {null}, argumentType, null);
