@@ -23,6 +23,7 @@ import static org.junit.Assert.assertThat;
 import static org.mockito.Mockito.when;
 import java.util.List;
 import org.apache.skywalking.apm.agent.core.context.ContextSnapshot;
+import org.apache.skywalking.apm.agent.core.context.MockContextSnapshot;
 import org.apache.skywalking.apm.agent.core.context.trace.AbstractTracingSpan;
 import org.apache.skywalking.apm.agent.core.context.trace.TraceSegment;
 import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.EnhancedInstance;
@@ -55,7 +56,6 @@ public class OnExceptionInterceptorTest {
     @Rule
     public MockitoRule rule = MockitoJUnit.rule();
 
-    @Mock
     private ContextSnapshot contextSnapshot;
     private SendCallBackEnhanceInfo enhanceInfo;
 
@@ -65,6 +65,7 @@ public class OnExceptionInterceptorTest {
     @Before
     public void setUp() {
         exceptionInterceptor = new OnExceptionInterceptor();
+        contextSnapshot = MockContextSnapshot.INSTANCE.mockContextSnapshot();
 
         enhanceInfo = new SendCallBackEnhanceInfo("test", contextSnapshot);
         when(enhancedInstance.getSkyWalkingDynamicField()).thenReturn(enhanceInfo);
