@@ -20,13 +20,16 @@ package org.apache.skywalking.apm.plugin.spring.cloud.gateway.v3x.define;
 import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.ClassInstanceMethodsEnhancePluginDefine;
 
 /**
- * This abstract class defines the <code>witnessClasses()</code> method,
- * and other plugin define classes need to inherit from this class
+ * This abstract class defines the <code>witnessClasses()</code> method, and other plugin define classes need to inherit
+ * from this class
  */
 public abstract class AbstractGatewayV3EnhancePluginDefine extends ClassInstanceMethodsEnhancePluginDefine {
 
     @Override
     protected String[] witnessClasses() {
-        return new String[]{"org.springframework.cloud.gateway.config.GatewayLoadBalancerProperties"};
+        return new String[] {
+            "org.springframework.cloud.gateway.config.GatewayLoadBalancerProperties",
+            "org.springframework.web.client.AsyncRestTemplate"
+        };
     }
 }
