@@ -17,8 +17,15 @@
 
 package org.apache.skywalking.apm.plugin.spring.cloud.gateway.v4x.define;
 
+import org.apache.skywalking.apm.agent.core.plugin.WitnessMethod;
 import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.ClassInstanceMethodsEnhancePluginDefine;
 
+import java.util.Collections;
+import java.util.List;
+
+import static net.bytebuddy.matcher.ElementMatchers.named;
+import static net.bytebuddy.matcher.ElementMatchers.returns;
+
 /**
  * This abstract class defines the <code>witnessClasses()</code> method,
  * and other plugin define classes need to inherit from this class
@@ -32,4 +39,12 @@ public abstract class AbstractGatewayV4EnhancePluginDefine extends ClassInstance
     protected String[] witnessClasses() {
         return new String[]{"org.springframework.cloud.gateway.filter.factory.cache.LocalResponseCacheProperties"};
     }
+
+    @Override
+    protected List<WitnessMethod> witnessMethods() {
+        return Collections.singletonList(
+                new WitnessMethod("org.springframework.cloud.gateway.config.LocalResponseCacheAutoConfiguration",
+                        named("responseCacheSizeWeigher").
+                                and(returns(named("org.springframework.cloud.gateway.filter.factory.cache.ResponseCacheSizeWeigher")))));
+    }
 }
