@@ -18,14 +18,17 @@
 
 package org.apache.skywalking.apm.testcase.jedis.controller;
 
+import redis.clients.jedis.DefaultJedisSocketFactory;
 import redis.clients.jedis.Jedis;
+import redis.clients.jedis.JedisSocketFactory;
 import redis.clients.jedis.Transaction;
 
 public class RedisTransactionCommandExecutor implements AutoCloseable {
     private Jedis jedis;
 
     public RedisTransactionCommandExecutor(String host, Integer port) {
-        jedis = new Jedis(host, port);
+        JedisSocketFactory jedisSocketFactory = new DefaultJedisSocketFactory(host, port, 1000, 1000, false, null, null, null);
+        jedis = new Jedis(jedisSocketFactory);
     }
 
     public void multiExecute() {
@@ -35,6 +38,13 @@ public class RedisTransactionCommandExecutor implements AutoCloseable {
         pipeline.exec();
     }
 
+    public void multiDiscard() {
+        Transaction pipeline = jedis.multi();
+        pipeline.set("key", "a");
+        pipeline.expire("key", 5);
+        pipeline.discard();
+    }
+
     public void close() throws Exception {
         jedis.close();
     }
