@@ -18,7 +18,4 @@
 
 home="$(cd "$(dirname $0)"; pwd)"
 
-# enable class cache feature
-export agent_opts="$agent_opts -Dskywalking.agent.is_cache_enhanced_class=true -Dskywalking.agent.class_cache_mode=MEMORY"
-
 java -jar ${agent_opts} ${home}/../libs/retransform-class-scenario.jar &
\ No newline at end of file
